Encoding: UTF-8
Package: PowerTOST
Type: Package
Title: Power and Sample Size for (Bio)Equivalence Studies
Version: 1.5-7
Date: 2025-09-16
Authors@R: c(person("Detlew", "Labes",
               role = c("aut","cre"),
               email = "DetlewLabes@gmx.de",
               comment = c(ORCID = "0000-0003-2169-426X")),
             person("Helmut", "Schütz",
               role = c("aut"),
               email = "helmut.schuetz@bebac.at",
               comment = c(ORCID = "0000-0002-1167-7880")),
             person("Benjamin", "Lang",
               role = c("aut"),
               email ="lang.be@icloud.com"))
Description: Contains functions to calculate power and sample size for
    various study designs used in bioequivalence studies. Use known.designs() to
    see the designs supported. Power and sample size can be obtained based on
    different methods, amongst them prominently the TOST procedure (two one-sided
    t-tests). See README and NEWS for further information.
Imports: mvtnorm, stats, utils, graphics, grDevices, cubature (>=
        1.3-6)
Suggests: crossdes, knitr, rmarkdown, tufte, emmeans
ByteCompile: yes
LazyData: true
VignetteBuilder: knitr
URL: https://github.com/Detlew/PowerTOST
BugReports: https://github.com/Detlew/PowerTOST/issues
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2025-09-17 15:22:10 UTC; Detlew
Author: Detlew Labes [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2169-426X>),
  Helmut Schütz [aut] (ORCID: <https://orcid.org/0000-0002-1167-7880>),
  Benjamin Lang [aut]
Maintainer: Detlew Labes <DetlewLabes@gmx.de>
Repository: CRAN
Date/Publication: 2025-09-23 07:20:02 UTC
Built: R 4.6.0; ; 2026-04-25 18:02:11 UTC; unix
